Get digital file information from a ServCat reference
Value
A tibble of file information. The API field fileSize is preserved.
When available, an additional fileSize_kb column is added by dividing
fileSize by 1024.
Examples
if (FALSE) { # \dontrun{
# Retrieve information for all files attached to a reference
get_files(140411)
# Retrieve information for a single file attached to a reference
files <- get_files(140411)
get_files(
reference_id = 140411,
file_id = files$resourceId[[1]]
)
# Retrieve file information using the secure API
get_files(
reference_id = 140411,
secure = TRUE
)
} # }