Retrieves the fixed list of Reference Types and adds ref_group_code by
parsing the comma-delimited type codes in the Reference Type Groups
description field. This join is included for convenience when building
Advanced Search criteria.
Retrieves the fixed list of Reference Types and adds ref_group_code by
parsing the comma-delimited type codes in the Reference Type Groups
description field. This join is included for convenience when building
Advanced Search criteria.